@@ -23,11 +23,10 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.core
-import constructs
-
 from ._jsii import *
 
+import aws_cdk.core
+
 
 @jsii.implements(aws_cdk.core.IInspectable)
 class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-dax.CfnCluster"):
@@ -38,7 +37,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
     cloudformationResource:
     :cloudformationResource:: AWS::DAX::Cluster
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, iam_role_arn: str, node_type: str, replication_factor: jsii.Number, availability_zones: typing.Optional[typing.List[str]]=None, cluster_name: typing.Optional[str]=None, description: typing.Optional[str]=None, notification_topic_arn: typing.Optional[str]=None, parameter_group_name: typing.Optional[str]=None, preferred_maintenance_window: typing.Optional[str]=None, security_group_ids: typing.Optional[typing.List[str]]=None, sse_specification: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["SSESpecificationProperty"]]]=None, subnet_group_name: typing.Optional[str]=None, tags: typing.Any=None) -> None:
+    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, iam_role_arn: str, node_type: str, replication_factor: jsii.Number, availability_zones: typing.Optional[typing.List[str]]=None, cluster_name: typing.Optional[str]=None, description: typing.Optional[str]=None, notification_topic_arn: typing.Optional[str]=None, parameter_group_name: typing.Optional[str]=None, preferred_maintenance_window: typing.Optional[str]=None, security_group_ids: typing.Optional[typing.List[str]]=None, sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]]=None, subnet_group_name: typing.Optional[str]=None, tags: typing.Any=None) -> None:
         """Create a new ``AWS::DAX::Cluster``.
 
         :param scope: - scope in which this resource is defined.
@@ -148,7 +147,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "iamRoleArn")
 
     @iam_role_arn.setter
-    def iam_role_arn(self, value: str):
+    def iam_role_arn(self, value: str) -> None:
         jsii.set(self, "iamRoleArn", value)
 
     @builtins.property
@@ -162,7 +161,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "nodeType")
 
     @node_type.setter
-    def node_type(self, value: str):
+    def node_type(self, value: str) -> None:
         jsii.set(self, "nodeType", value)
 
     @builtins.property
@@ -176,7 +175,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "replicationFactor")
 
     @replication_factor.setter
-    def replication_factor(self, value: jsii.Number):
+    def replication_factor(self, value: jsii.Number) -> None:
         jsii.set(self, "replicationFactor", value)
 
     @builtins.property
@@ -190,7 +189,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "availabilityZones")
 
     @availability_zones.setter
-    def availability_zones(self, value: typing.Optional[typing.List[str]]):
+    def availability_zones(self, value: typing.Optional[typing.List[str]]) -> None:
         jsii.set(self, "availabilityZones", value)
 
     @builtins.property
@@ -204,7 +203,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "clusterName")
 
     @cluster_name.setter
-    def cluster_name(self, value: typing.Optional[str]):
+    def cluster_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "clusterName", value)
 
     @builtins.property
@@ -218,7 +217,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "description")
 
     @description.setter
-    def description(self, value: typing.Optional[str]):
+    def description(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "description", value)
 
     @builtins.property
@@ -232,7 +231,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "notificationTopicArn")
 
     @notification_topic_arn.setter
-    def notification_topic_arn(self, value: typing.Optional[str]):
+    def notification_topic_arn(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "notificationTopicArn", value)
 
     @builtins.property
@@ -246,7 +245,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "parameterGroupName")
 
     @parameter_group_name.setter
-    def parameter_group_name(self, value: typing.Optional[str]):
+    def parameter_group_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "parameterGroupName", value)
 
     @builtins.property
@@ -260,7 +259,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "preferredMaintenanceWindow")
 
     @preferred_maintenance_window.setter
-    def preferred_maintenance_window(self, value: typing.Optional[str]):
+    def preferred_maintenance_window(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "preferredMaintenanceWindow", value)
 
     @builtins.property
@@ -274,12 +273,12 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "securityGroupIds")
 
     @security_group_ids.setter
-    def security_group_ids(self, value: typing.Optional[typing.List[str]]):
+    def security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
         jsii.set(self, "securityGroupIds", value)
 
     @builtins.property
     @jsii.member(jsii_name="sseSpecification")
-    def sse_specification(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["SSESpecificationProperty"]]]:
+    def sse_specification(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]]:
         """``AWS::DAX::Cluster.SSESpecification``.
 
         see
@@ -288,7 +287,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "sseSpecification")
 
     @sse_specification.setter
-    def sse_specification(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["SSESpecificationProperty"]]]):
+    def sse_specification(self, value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "SSESpecificationProperty"]]) -> None:
         jsii.set(self, "sseSpecification", value)
 
     @builtins.property
@@ -302,12 +301,12 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
         return jsii.get(self, "subnetGroupName")
 
     @subnet_group_name.setter
-    def subnet_group_name(self, value: typing.Optional[str]):
+    def subnet_group_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "subnetGroupName", value)
 
     @jsii.data_type(jsii_type="@aws-cdk/aws-dax.CfnCluster.SSESpecificationProperty", jsii_struct_bases=[], name_mapping={'sse_enabled': 'sseEnabled'})
     class SSESpecificationProperty():
-        def __init__(self, *, sse_enabled: typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]=None) -> None:
+        def __init__(self, *, sse_enabled: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None) -> None:
             """
             :param sse_enabled: ``CfnCluster.SSESpecificationProperty.SSEEnabled``.
 
@@ -319,7 +318,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
             if sse_enabled is not None: self._values["sse_enabled"] = sse_enabled
 
         @builtins.property
-        def sse_enabled(self) -> typing.Optional[typing.Union[typing.Optional[bool], typing.Optional[aws_cdk.core.IResolvable]]]:
+        def sse_enabled(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
             """``CfnCluster.SSESpecificationProperty.SSEEnabled``.
 
             see
@@ -340,7 +339,7 @@ class CfnCluster(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@
 
 @jsii.data_type(jsii_type="@aws-cdk/aws-dax.CfnClusterProps", jsii_struct_bases=[], name_mapping={'iam_role_arn': 'iamRoleArn', 'node_type': 'nodeType', 'replication_factor': 'replicationFactor', 'availability_zones': 'availabilityZones', 'cluster_name': 'clusterName', 'description': 'description', 'notification_topic_arn': 'notificationTopicArn', 'parameter_group_name': 'parameterGroupName', 'preferred_maintenance_window': 'preferredMaintenanceWindow', 'security_group_ids': 'securityGroupIds', 'sse_specification': 'sseSpecification', 'subnet_group_name': 'subnetGroupName', 'tags': 'tags'})
 class CfnClusterProps():
-    def __init__(self, *, iam_role_arn: str, node_type: str, replication_factor: jsii.Number, availability_zones: typing.Optional[typing.List[str]]=None, cluster_name: typing.Optional[str]=None, description: typing.Optional[str]=None, notification_topic_arn: typing.Optional[str]=None, parameter_group_name: typing.Optional[str]=None, preferred_maintenance_window: typing.Optional[str]=None, security_group_ids: typing.Optional[typing.List[str]]=None, sse_specification: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnCluster.SSESpecificationProperty"]]]=None, subnet_group_name: typing.Optional[str]=None, tags: typing.Any=None) -> None:
+    def __init__(self, *, iam_role_arn: str, node_type: str, replication_factor: jsii.Number, availability_zones: typing.Optional[typing.List[str]]=None, cluster_name: typing.Optional[str]=None, description: typing.Optional[str]=None, notification_topic_arn: typing.Optional[str]=None, parameter_group_name: typing.Optional[str]=None, preferred_maintenance_window: typing.Optional[str]=None, security_group_ids: typing.Optional[typing.List[str]]=None, sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]]=None, subnet_group_name: typing.Optional[str]=None, tags: typing.Any=None) -> None:
         """Properties for defining a ``AWS::DAX::Cluster``.
 
         :param iam_role_arn: ``AWS::DAX::Cluster.IAMRoleARN``.
@@ -467,7 +466,7 @@ class CfnClusterProps():
         return self._values.get('security_group_ids')
 
     @builtins.property
-    def sse_specification(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnCluster.SSESpecificationProperty"]]]:
+    def sse_specification(self) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]]:
         """``AWS::DAX::Cluster.SSESpecification``.
 
         see
@@ -584,7 +583,7 @@ class CfnParameterGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
         return jsii.get(self, "parameterNameValues")
 
     @parameter_name_values.setter
-    def parameter_name_values(self, value: typing.Any):
+    def parameter_name_values(self, value: typing.Any) -> None:
         jsii.set(self, "parameterNameValues", value)
 
     @builtins.property
@@ -598,7 +597,7 @@ class CfnParameterGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
         return jsii.get(self, "description")
 
     @description.setter
-    def description(self, value: typing.Optional[str]):
+    def description(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "description", value)
 
     @builtins.property
@@ -612,7 +611,7 @@ class CfnParameterGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_
         return jsii.get(self, "parameterGroupName")
 
     @parameter_group_name.setter
-    def parameter_group_name(self, value: typing.Optional[str]):
+    def parameter_group_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "parameterGroupName", value)
 
 
@@ -752,7 +751,7 @@ class CfnSubnetGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "subnetIds")
 
     @subnet_ids.setter
-    def subnet_ids(self, value: typing.List[str]):
+    def subnet_ids(self, value: typing.List[str]) -> None:
         jsii.set(self, "subnetIds", value)
 
     @builtins.property
@@ -766,7 +765,7 @@ class CfnSubnetGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "description")
 
     @description.setter
-    def description(self, value: typing.Optional[str]):
+    def description(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "description", value)
 
     @builtins.property
@@ -780,7 +779,7 @@ class CfnSubnetGroup(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "subnetGroupName")
 
     @subnet_group_name.setter
-    def subnet_group_name(self, value: typing.Optional[str]):
+    def subnet_group_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "subnetGroupName", value)
 
 
